



grcc %PREFIX%\\Library\\share\\gr-dect2\\examples\\dect2.grc
IF %ERRORLEVEL% NEQ 0 exit /B 1
grcc %PREFIX%\\Library\\share\\gr-dect2\\examples\\dect2_b200.grc
IF %ERRORLEVEL% NEQ 0 exit /B 1
grcc %PREFIX%\\Library\\share\\gr-dect2\\examples\\dect2_Hackrf.grc
IF %ERRORLEVEL% NEQ 0 exit /B 1
grcc %PREFIX%\\Library\\share\\gr-dect2\\examples\\dect2_plutosdr.grc
IF %ERRORLEVEL% NEQ 0 exit /B 1
grcc %PREFIX%\\Library\\share\\gr-dect2\\examples\\dect2_soapy.grc
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gnuradio\\dect2\\api.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\gnuradio-dect2.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gnuradio-dect2.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\dect2_console.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\dect2_packet_decoder.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\dect2_packet_receiver.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\dect2_phase_diff.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
